===============================
pywaterml
===============================


.. image:: https://img.shields.io/travis/romer8/https://github.com/romer8/pywaterml.git.svg
        :target: https://travis-ci.org/romer8/https://github.com/romer8/pywaterml.git
.. image:: https://circleci.com/gh/romer8/https://github.com/romer8/pywaterml.git.svg?style=svg
    :target: https://circleci.com/gh/romer8/https://github.com/romer8/pywaterml.git
.. image:: https://codecov.io/gh/romer8/https://github.com/romer8/pywaterml.git/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/romer8/https://github.com/romer8/pywaterml.git


The pywaterml is a package that lets you handle WaterML functions such as GetValues, GetSitesInfo, etc. In addition it lets offers extra functions such as mean interpolation for data with gaps
